Range-v3: ranges::v3::as_function_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Instances and minimal complete definitions | Public Member Functions | List of all members
ranges::v3::as_function_fn Struct Reference
Utility

## Public Member Functions
template<typename R , typename... Args>
constexpr ptr_fn_< R, Args... > | operator() (R(*p)(Args...)) const
template<typename R , typename T >
auto | operator() (R T::*p) const -> decltype(_mem_fn(p))
template<typename T , typename U = detail::decay_t<T>>
constexpr auto | operator() (T &&t) const -> meta::if_c<!std::is_pointer< U >::value &&!std::is_member_pointer< U >::value, T >